@@ -2,7 +2,7 @@ package HTML::Selector::XPath;
 
 use strict;
 use 5.008_001;
-our $VERSION = '0.13';
+our $VERSION = '0.15';
 
 require Exporter;
 our @EXPORT_OK = qw(selector_to_xpath);
@@ -26,7 +26,7 @@ my $reg = {
     # attribute value match
     attr2   => qr/^\[ \s* ($ident) \s*
         ( [~|*^\$!]? = ) \s*
-        (?: ($ident) | "([^"]*)" ) \s* \] /x,
+        (?: ($ident) | "([^"]*)" | '([^']*)') \s* \] /x,
     badattr => qr/^\[/,
     attrN   => qr/^:not\((.*?)\)/i, # this should be a parentheses matcher instead of a RE!
     pseudo  => qr/^:([()a-z0-9_+-]+)/i,
@@ -215,7 +215,7 @@ sub to_xpath {
             } elsif ($1 =~ /^nth-of-type\((\d+)\)$/) {
                 push @parts, "[$1]";
             } elsif ($1 =~ /^contains\($/) {
-                $rule =~ s/^\s*"([^"]*)"\s*\)\s*$//
+                $rule =~ s/^\s*"([^"]*)"\s*\)//
                     or die "Malformed string in :contains(): '$rule'";
                 push @parts, qq{[text()[contains(string(.),"$1")]]};
             } elsif ( $1 eq 'root') {
